==> viha-5.15.tar.gz: viha-5.15/tap-takt.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "tap";
$file = basename(__FILE__);

include "common.php";
include "tap-ok.php";

echo "
<html>
<head>
 <title>VIHA - Tapahtumakirjaus</title>
</head>
" . body_bgcolor() . "
<h1>" . ota_paivystys_nimi() . ", vapaamuotoinen tapahtumakirjaus</h1>
";

taktiset_linkit();

$id = get_nro_0('id');
$ryhma_id = get_nro_1('ryhma_id');
$tap = get_txt('tap');

$add = get_txt('add');
$clear = get_txt('clear');

oltava_sallittu($file, $table, $id);

if (($add != '') && saa_tehda("$file:add")) {
  $ret = tap_add_ok($herja,s('alue'),
		    s('paivystys'),
		    $ryhma_id,$tap);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "INSERT INTO $table
       SET alue_id = " . s("alue") . ",
           paivystys_id = " . s("paivystys") . ",
           ryhma_id = $ryhma_id,
           tap = '$tap',
           ts = '$now'";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot listty.\n";
    $clear = "ADD";
    loki("$sql id=" . last_insert_id());
    taktinen_loki(ota_kutsu($ryhma_id) . ": $tap");
  }
  p_herja($ret,$herja);
 }

if ($clear != '') {
    $id = "0";
    $ryhma_id = "1";
    $tap = '';
}

echo "<form action=\"\" method=\"GET\">\n";
echo "<p><table border=0>\n";

echo "<tr><td>Id:";
if ($id == "0") {
  echo "<td>(tehdn uusi)\n";
} else {
  echo "<td>$id\n";
}
echo "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

echo "<tr><td>Ryhm:";
echo "<td>\n";
select_ryhma_kutsu("VIESTI");

echo "<tr><td>Kirjaus:";
echo "<td><input type=\"text\" name=\"tap\" size=64 maxlength=255";
echo " value=\"$ra\">\n";

echo "</table>\n";

echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";

$limit = 20;
echo "<p>$limit uusinta tapahtumaa:";
$sql =
  "SELECT tap.id, tap.tap, tap.ts, ryhma.kutsu
   FROM tap, ryhma
   WHERE ryhma.id = tap.ryhma_id
   ORDER BY tap.ts DESC";
$result = my_mysql_query($sql);
echo "<p><TABLE BORDER=1>\n";
echo tr_bgcolor()
  . "<TH>Id<TH>Aikaleima<TH>Ryhm<TH>Tapahtuma\n";
$shown = 0;
while ($a = mysql_fetch_array($result)) {
  # just skip those items we do not have permission to
  if (visible_operation_tab($herja,$table,$a['id'],false) == 2)
    continue; 
  echo "<TR><TD>$a[id]",
    "<TD>" . vain_hhmm($a['ts']),
    "<TD>$a[kutsu]",
    "<TD>$a[tap]";
  $shown ++;
  if ($shown >= $limit)
    break;
 }
echo "</TABLE>";

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: tap-takt.php,v 1.9 2009/04/18 16:06:56 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/tap-takt.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "tap";
$file = basename(__FILE__);

include "common.php";
include "tap-ok.php";

echo "
<html>
<head>
 <title>VIHA - Tapahtumakirjaus</title>
</head>
" . body_bgcolor() . "
<h1>" . muotoile_operaatio() . ", vapaamuotoinen tapahtumakirjaus</h1>
";

taktiset_linkit();

$id = get_nro_0('id');
$ryhma_id = get_nro_1('ryhma_id');
$tap = get_txt('tap');

$add = get_txt('add');
$clear = get_txt('clear');

oltava_sallittu($file, $table, $id);

if (($add != '') && saa_tehda("$file:add")) {
  $ret = tap_add_ok($herja,s('alue'),
		    s('paivystys'),
		    $ryhma_id,$tap);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "INSERT INTO $table
       SET alue_id = " . s("alue") . ",
           paivystys_id = " . s("paivystys") . ",
           ryhma_id = $ryhma_id,
           tap = '$tap',
           ts = '$now'";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot listty.\n";
    $clear = "ADD";
    loki("$sql id=" . last_insert_id());
    taktinen_loki(ota_kutsu($ryhma_id) . ": $tap");
  }
  p_herja($ret,$herja);
 }

if ($clear != '') {
    $id = "0";
    $ryhma_id = "1";
    $tap = '';
}

echo "<form action=\"\" method=\"GET\">\n";
echo "<p><table border=0>\n";

echo "<tr><td>Id:";
if ($id == "0") {
  echo "<td>(tehdn uusi)\n";
} else {
  echo "<td>$id\n";
}
echo "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

echo "<tr><td>Ryhm:";
echo "<td>\n";
select_ryhma_kutsu("VIESTI");

echo "<tr><td>Kirjaus:";
echo "<td><input type=\"text\" name=\"tap\" size=64 maxlength=255";
echo " value=\"$ra\">\n";

echo "</table>\n";

echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";

$limit = 20;
echo "<p>$limit uusinta tapahtumaa:";
$sql =
  "SELECT tap.id, tap.tap, tap.ts, ryhma.kutsu
   FROM tap, ryhma
   WHERE ryhma.id = tap.ryhma_id
   ORDER BY tap.ts DESC";
$result = my_mysql_query($sql);
echo "<p><TABLE BORDER=1>\n";
echo tr_vaalsin()
  . "<TH>Id<TH>Aikaleima<TH>Ryhm<TH>Tapahtuma\n";
$shown = 0;
while ($a = mysql_fetch_array($result)) {
  # just skip those items we do not have permission to
  if (visible_operation_tab($herja,$table,$a['id'],false) == 2)
    continue; 
  echo "<TR><TD>$a[id]",
    "<TD>" . vain_hhmm($a['ts']),
    "<TD>$a[kutsu]",
    "<TD>$a[tap]";
  $shown ++;
  if ($shown >= $limit)
    break;
 }
echo "</TABLE>";

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: tap-takt.php,v 1.11 2009/09/29 16:09:15 riku Exp $ -->
